
# Slot: role


the role played by the slot range

URI: [meta:role](https://w3id.org/biolink/biolinkml/meta/role)

## Domain and Range

[SlotDefinition](SlotDefinition.md) ->  <sub>OPT</sub> [String](String.md)

## Parents


## Children


## Used by

 * [SlotDefinition](SlotDefinition.md)
